{#def funders, search_link #}

<div class='detail-subfields'>
    {% for funder in funders %}
        {% if funder.projectID %}
            <strong>{{ funder.projectID }}</strong>
            <br/>
        {% endif %}
        {% if funder.projectName %}
            {{ funder.projectName }}
            <br/>
        {% endif %}
        {% if funder.fundingProgram %}
            {{ funder.fundingProgram }}
            <br/>
        {% endif %}
        {% if funder.funder %}
            <VocabularyItem vocabulary={funder.funder} search_link={search_link} searchFacet="metadata_fundingReferences_funder" vocabulary_type="funders"></VocabularyItem> 
            <br/>
        {% endif %}
        {% if not loop.last %}
            <div class="rel-mb-1"></div>
        {% endif %}
    {% endfor %}
</div>
